==> igniteui-react-charts-16.6.4.tgz: package/ES5/igr-radial-line-series.js <==
import * as tslib_1 from "tslib";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES5/UnknownValuePlotting";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialLineSeries } from "./RadialLineSeries";
import { ensureEnum } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents a IgxDataChartComponent radial line series.
*/
var IgrRadialLineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrRadialLineSeries, _super);
    function IgrRadialLineSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrRadialLineSeries.prototype.createImplementation = function () {
        return new RadialLineSeries();
    };
    Object.defineProperty(IgrRadialLineSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrRadialLineSeries.prototype, "unknownValuePlotting", {
        /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
        get: function () {
            return this.i.oi;
        },
        set: function (v) {
            this.i.oi = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * When overridden in a derived class, is invoked whenever application code or internal processes
     * call ApplyTemplate.
    
    */
    IgrRadialLineSeries.prototype.onApplyTemplate = function () {
        this.i.ac();
    };
    return IgrRadialLineSeries;
}(IgrAnchoredRadialSeries));
export { IgrRadialLineSeries };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-radial-line-series.js <==
import * as tslib_1 from "tslib";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES5/UnknownValuePlotting";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialLineSeries } from "./RadialLineSeries";
import { ensureEnum } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents a IgxDataChartComponent radial line series.
*/
var IgrRadialLineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrRadialLineSeries, _super);
    function IgrRadialLineSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrRadialLineSeries.prototype.createImplementation = function () {
        return new RadialLineSeries();
    };
    Object.defineProperty(IgrRadialLineSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrRadialLineSeries.prototype, "unknownValuePlotting", {
        /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
        get: function () {
            return this.i.ok;
        },
        set: function (v) {
            this.i.ok = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * When overridden in a derived class, is invoked whenever application code or internal processes
     * call ApplyTemplate.
    
    */
    IgrRadialLineSeries.prototype.onApplyTemplate = function () {
        this.i.ac();
    };
    return IgrRadialLineSeries;
}(IgrAnchoredRadialSeries));
export { IgrRadialLineSeries };
